
# This file was generated by 'versioneer.py' (0.17) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2017-10-17T12:49:55-0500",
 "dirty": false,
 "error": null,
 "full-revisionid": "62be04c1fcedde3745f4486019c2637c0ae3b7e0",
 "version": "3.0.27"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
