



where conda-build
if errorlevel 1 exit 1
conda-build -h
if errorlevel 1 exit 1
where conda-convert
if errorlevel 1 exit 1
conda-convert -h
if errorlevel 1 exit 1
where conda-develop
if errorlevel 1 exit 1
conda-develop -h
if errorlevel 1 exit 1
where conda-index
if errorlevel 1 exit 1
conda-index -h
if errorlevel 1 exit 1
where conda-inspect
if errorlevel 1 exit 1
conda-inspect -h
if errorlevel 1 exit 1
where conda-metapackage
if errorlevel 1 exit 1
conda-metapackage -h
if errorlevel 1 exit 1
where conda-render
if errorlevel 1 exit 1
conda-render -h
if errorlevel 1 exit 1
where conda-skeleton
if errorlevel 1 exit 1
conda-skeleton -h
if errorlevel 1 exit 1
python test_bdist_conda_setup.py bdist_conda --help
if errorlevel 1 exit 1
exit 0
